@@ -130,7 +130,7 @@ fallback_shape (PangoEngineShape *engine,
 		PangoFont        *font,
 		const char       *text,
 		gint              length,
-		PangoAnalysis    *analysis,
+		const PangoAnalysis *analysis,
 		PangoGlyphString *glyphs)
 {
   PangoFcFont *fc_font = PANGO_FC_FONT (font);
@@ -324,7 +324,7 @@ basic_engine_shape (PangoEngineShape *engine,
 		    PangoFont        *font,
 		    const char       *text,
 		    gint              length,
-		    PangoAnalysis    *analysis,
+		    const PangoAnalysis *analysis,
 		    PangoGlyphString *glyphs)
 {
   PangoFcFont *fc_font;
