@@ -2,8 +2,8 @@
 
 # Build zipfiles for Pango on Win32: separate runtime and developer packages
 
-ZIP=/tmp/pango-1.11.4-`date +%Y%m%d`.zip
-DEVZIP=/tmp/pango-dev-1.11.4-`date +%Y%m%d`.zip
+ZIP=/tmp/pango-1.11.5.zip
+DEVZIP=/tmp/pango-dev-1.11.5.zip
 cd /home/behdad/.local
 
 rm $ZIP
