@@ -80,8 +80,8 @@ static const PangoFontDescription pfd_defaults = {
  * 
  * Creates a new font description structure with all fields unset.
  * 
- * Return value: the newly-created #PangoFontDescription. Use
- * pango_font_description_free() to free the result.
+ * Return value: the newly allocated #PangoFontDescription, which
+ *               should be freed using pango_font_description_free().
  **/
 PangoFontDescription *
 pango_font_description_new (void)
@@ -160,7 +160,9 @@ pango_font_description_set_family_static (PangoFontDescription *desc,
  * Gets the family name field of a font description. See
  * pango_font_description_set_family().
  * 
- * Return value: The family name field. (Will be %NULL if not previously set.)
+ * Return value: the family name field for the font description, or
+ *               %NULL if not previously set.  This has the same life-time
+ *               as the font description itself and should not be freed.
  **/
 G_CONST_RETURN char *
 pango_font_description_get_family (const PangoFontDescription *desc)
@@ -591,8 +593,8 @@ pango_font_description_better_match (const PangoFontDescription *desc,
  * 
  * Make a copy of a #PangoFontDescription.
  * 
- * Return value: a newly-allocated #PangoFontDescription. This value
- *               must be freed using pango_font_description_free().
+ * Return value: the newly allocated #PangoFontDescription, which should
+ *               be freed with pango_font_description_free().
  **/
 PangoFontDescription *
 pango_font_description_copy  (const PangoFontDescription  *desc)
@@ -619,8 +621,8 @@ pango_font_description_copy  (const PangoFontDescription  *desc)
  * be used until @desc is modififed or freed. This is meant to be used
  * when the copy is only needed temporarily.
  * 
- * Return value: a newly-allocated #PangoFontDescription. This value
- *               must be freed using pango_font_description_free().
+ * Return value: the newly allocated #PangoFontDescription, which should
+ *               be freed with pango_font_description_free().
  **/
 PangoFontDescription *
 pango_font_description_copy_static (const PangoFontDescription *desc)
@@ -1164,27 +1166,27 @@ pango_font_get_glyph_extents  (PangoFont      *font,
 			       PangoRectangle *ink_rect,
 			       PangoRectangle *logical_rect)
 {
-  if (G_UNLIKELY (font == NULL))
+  if (G_UNLIKELY (!PANGO_IS_FONT (font)))
     {
       
       if (!_pango_warning_history.get_glyph_extents)
         {
 	  _pango_warning_history.get_glyph_extents = TRUE;
-	  g_critical ("pango_font_get_glyph_extents called with font == NULL, expect ugly output");
+	  g_critical ("pango_font_get_glyph_extents called with bad font, expect ugly output");
 	}
       if (ink_rect)
         {
-	  ink_rect->x = 0;
-	  ink_rect->y = 0;
-	  ink_rect->height = 12 * PANGO_SCALE;
-	  ink_rect->width = 12 * PANGO_SCALE;
+	  ink_rect->x = PANGO_SCALE;
+	  ink_rect->y = - (PANGO_UNKNOWN_GLYPH_HEIGHT - 1) * PANGO_SCALE;
+	  ink_rect->height = (PANGO_UNKNOWN_GLYPH_HEIGHT - 2) * PANGO_SCALE;
+	  ink_rect->width = (PANGO_UNKNOWN_GLYPH_WIDTH - 2) * PANGO_SCALE;
         }
       if (logical_rect)
         {
-	  logical_rect->x = 0;
-	  logical_rect->y = 0;
-	  logical_rect->height = 12 * PANGO_SCALE;
-	  logical_rect->width = 12 * PANGO_SCALE;
+	  logical_rect->x = logical_rect->y = 0;
+	  logical_rect->y = - PANGO_UNKNOWN_GLYPH_HEIGHT * PANGO_SCALE;
+	  logical_rect->height = PANGO_UNKNOWN_GLYPH_HEIGHT * PANGO_SCALE;
+	  logical_rect->width = PANGO_UNKNOWN_GLYPH_WIDTH * PANGO_SCALE;
 	}
       return;
     }
@@ -1277,7 +1279,8 @@ pango_font_metrics_new (void)
 PangoFontMetrics *
 pango_font_metrics_ref (PangoFontMetrics *metrics)
 {
-  g_return_val_if_fail (metrics != NULL, NULL);
+  if (!metrics)
+    return NULL;
   
   metrics->ref_count++;
 
@@ -1295,7 +1298,8 @@ pango_font_metrics_ref (PangoFontMetrics *metrics)
 void
 pango_font_metrics_unref (PangoFontMetrics *metrics)
 {
-  g_return_if_fail (metrics != NULL);
+  if (!metrics)
+    return;
   g_return_if_fail (metrics->ref_count > 0 );
   
   metrics->ref_count--;
