@@ -82,6 +82,7 @@ pango_fc_font_class_init (PangoFcFontClass *class)
 
   class->has_char = pango_fc_font_real_has_char;
   class->get_glyph = pango_fc_font_real_get_glyph;
+  class->get_unknown_glyph = NULL;
   
   object_class->finalize = pango_fc_font_finalize;
   object_class->set_property = pango_fc_font_set_property;
@@ -434,7 +435,7 @@ pango_fc_font_create_metrics_for_context (PangoFcFont   *fcfont,
   g_object_unref (layout);
 
   return metrics;
-}		    
+}
 
 /* This function is cut-and-pasted into pangocairo-fcfont.c - it might be
  * better to add a virtual fcfont->create_context (font).
@@ -468,7 +469,7 @@ pango_fc_font_get_metrics (PangoFont     *font,
 	return pango_font_metrics_new ();
 
       info = g_slice_new0 (PangoFcMetricsInfo);
-      
+
       fcfont->metrics_by_lang = g_slist_prepend (fcfont->metrics_by_lang, 
 						 info);
 	
@@ -631,6 +632,8 @@ pango_fc_font_get_glyph (PangoFcFont *font,
  * Returns the index of a glyph suitable for drawing @wc as an
  * unknown character.
  *
+ * Use PANGO_GET_UNKNOWN_GLYPH() instead.
+ *
  * Return value: a glyph index into @font.
  *
  * Since: 1.4
@@ -639,9 +642,10 @@ PangoGlyph
 pango_fc_font_get_unknown_glyph (PangoFcFont *font,
 				 gunichar     wc)
 {
-  g_return_val_if_fail (PANGO_IS_FC_FONT (font), 0);
+  if (font && PANGO_FC_FONT_GET_CLASS (font)->get_unknown_glyph)
+    return PANGO_FC_FONT_GET_CLASS (font)->get_unknown_glyph (font, wc);
 
-  return PANGO_FC_FONT_GET_CLASS (font)->get_unknown_glyph (font, wc);
+  return PANGO_GET_UNKNOWN_GLYPH (wc);
 }
 
 void
@@ -813,7 +817,7 @@ pango_fc_font_get_raw_extents (PangoFcFont    *fcfont,
 
   face = PANGO_FC_FONT_LOCK_FACE (fcfont);
 
-  if (!glyph)
+  if (glyph == PANGO_GLYPH_EMPTY)
     gm = NULL;
   else
     gm = get_per_char (face, load_flags, glyph);
