@@ -40,13 +40,13 @@
 void
 pango_shape (const gchar      *text, 
              gint              length, 
-             PangoAnalysis    *analysis,
+             const PangoAnalysis *analysis,
              PangoGlyphString *glyphs)
 {
   int i;
   int last_cluster = -1;
 
-  if (G_LIKELY (analysis->shape_engine && analysis->font))
+  if (G_LIKELY (PANGO_IS_ENGINE_SHAPE (analysis->shape_engine) && PANGO_IS_FONT (analysis->font)))
     {
       _pango_engine_shape_shape (analysis->shape_engine, analysis->font,
 				 text, length, analysis, glyphs);
@@ -73,7 +73,7 @@ pango_shape (const gchar      *text,
 	      s = pango_font_description_to_string (desc);
 	      pango_font_description_free (desc);
 
-	      g_warning ("shape engine failure, expect ugly output. the offending font is `%s'", s);
+	      g_warning ("shape engine failure, expect ugly output. the offending font is '%s'", s);
 
 	      g_free (s);
 
@@ -84,15 +84,17 @@ pango_shape (const gchar      *text,
     }
   else
     {
-      if (!analysis->shape_engine && !_pango_warning_history.shape_shape_engine)
+      if (!PANGO_IS_ENGINE_SHAPE (analysis->shape_engine) &&
+	  !_pango_warning_history.shape_shape_engine)
         {
-	  _pango_warning_history.shape_font = TRUE;
-	  g_critical ("pango_shape called with analysis->shape_engine == NULL, expect ugly output");
+	  _pango_warning_history.shape_shape_engine = TRUE;
+	  g_critical ("pango_shape called with bad shape_engine, expect ugly output");
 	}
-      if (!analysis->font && !_pango_warning_history.shape_font)
+      if (!PANGO_IS_FONT (analysis->font) &&
+	  !_pango_warning_history.shape_font)
         {
 	  _pango_warning_history.shape_font = TRUE;
-	  g_critical ("pango_shape called with analysis->font == NULL, expect ugly output");
+	  g_critical ("pango_shape called with bad font, expect ugly output");
 	}
 
       glyphs->num_glyphs = 0;
@@ -100,20 +102,10 @@ pango_shape (const gchar      *text,
 
   if (!glyphs->num_glyphs)
     {
-      /* If failed to get glyphs, put a whitespace glyph per character
-       */
-      pango_glyph_string_set_size (glyphs, g_utf8_strlen (text, length));
+      PangoEngineShape *fallback_engine = _pango_get_fallback_shaper ();
 
-      for (i = 0; i < glyphs->num_glyphs; i++)
-        {
-	  glyphs->glyphs[i].glyph = 0;
-	  
-	  glyphs->glyphs[i].geometry.x_offset = 0;
-	  glyphs->glyphs[i].geometry.y_offset = 0;
-	  glyphs->glyphs[i].geometry.width = 10 * PANGO_SCALE;
-	  
-	  glyphs->log_clusters[i] = i;
-	}
+      _pango_engine_shape_shape (fallback_engine, analysis->font,
+				 text, length, analysis, glyphs);
     }
 
   /* Set glyphs[i].attr.is_cluster_start based on log_clusters[]
